# Generated by Django 2.1.2 on 2019-12-12 17:55

from django.db import migrations, models
import list_based_flavorpack.models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('list_based_flavorpack', '0005_auto_20191106_1755'),
    ]

    operations = [
        migrations.AddField(
            model_name='listbasedregion',
            name='database_name',
            field=models.CharField(blank=True, default=list_based_flavorpack.models.haikunate, help_text='The name of the database file if this is a database range.', max_length=50, null=True, verbose_name='Database File'),
        ),
        migrations.AlterField(
            model_name='listbasedregion',
            name='file_id',
            field=models.UUIDField(default=uuid.uuid1, help_text='If this range utilizes list-based files, then this willbe the name of the file located in the directory path.', verbose_name='File Name'),
        ),
    ]



# Generated by Django 2.2.3 on 2019-11-06 17:55

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('list_based_flavorpack', '0004_auto_20190214_1800'),
    ]

    operations = [
        migrations.AlterField(
            model_name='listbasedregion',
            name='authentication_info',
            field=models.ForeignKey(blank=True, help_text='The Authentication Info to use.', null=True, on_delete=django.db.models.deletion.SET_NULL, to='quartet_output.AuthenticationInfo', verbose_name='Authentication Info'),
        ),
        migrations.AlterField(
            model_name='listbasedregion',
            name='end_point',
            field=models.ForeignKey(blank=True, help_text='A protocol-specific endpoint defining whereany data will come from', null=True, on_delete=django.db.models.deletion.SET_NULL, to='quartet_output.EndPoint', verbose_name='End Point'),
        ),
        migrations.AlterField(
            model_name='listbasedregion',
            name='rule',
            field=models.ForeignKey(blank=True, help_text='A rule that may be executed by the region processing class.', null=True, on_delete=django.db.models.deletion.SET_NULL, to='quartet_capture.Rule', verbose_name='Processing Rule'),
        ),
        migrations.AlterField(
            model_name='listbasedregion',
            name='template',
            field=models.ForeignKey(blank=True, help_text='The Django/Jinja template to send a formatted request for number ranges', null=True, on_delete=django.db.models.deletion.SET_NULL, to='quartet_templates.Template', verbose_name='Message Template'),
        ),
        migrations.AlterField(
            model_name='processingparameters',
            name='list_based_region',
            field=models.ForeignKey(blank=True, help_text='A key-value pair object meant to hold parameters used for processing classes.', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='processing_parameters', to='list_based_flavorpack.ListBasedRegion', verbose_name='Processing Class Parameter'),
        ),
    ]



# This program is free software: you can redistribute it and/| modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, |
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY | FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Copyright 2018 SerialLab Corp.  All rights reserved.
from django.core.management.base import BaseCommand
from django.contrib.auth.models import Group, Permission
from django.db.models import Q
from django.utils.translation import gettext as _
from serialbox import models as sb_models
from list_based_flavorpack import models as lb_models
from copy import deepcopy
from uuid import uuid1
from quartet_capture import models


class Command(BaseCommand):
    help = _('Creates the default rfXcel and tracelink processing rules.')

    def handle(self, *args, **options):
        if not models.Rule.objects.exists(name='RFXCEL Number Request'):
            rule = models.Rule()
            rule.name = 'RFXCEL Number Request'
            rule.description = 'Initiates Number Requests to RFXCEL systems.'
            rule.save()
            step1 = models.Step()
            step1.rule = rule
            step1.name = 'Number Request Transport Step'
            step1.description = ('Uses task data to construct a request to '
                                 'an rfXcel system.')
            step1.step_class = ('list_based_flavorpack.steps.'
                                'NumberRequestTransportStep')
            step1.order = 1
            step1.save()
            step2 = models.Step()
            step2.rule = rule
            step2.name = 'RFXCEL Parse and Write Numbers'
            step2.description = ('Parses an inbound rfXcel number response '
                                 'and saves it to file.')
            step2.step_class = ('third_party_flavors.'
                                'rfxcel_number_response_step.'
                                'RFXCELNumberResponseParserStep')
            step2.order = 2
            step2.save()
        if not models.Rule.objects.exists(name='Tracelink Number Request'):
            rule2 = models.Rule('')
            rule2.name = 'Tracelink Number Request'
            rule2.description = ('Requests numbers from Tracelink and writes '
                                 'them persistently for use in Number '
                                 'Range distribution.')
            rule.save()
            step3 = models.Step()
            step3.rule = rule2
            step3.name = 'Number Request Transport Step'
            step3.description = ('Requests numbers and passes the response '
                                 'to the next step (for parsing)')
            step3.step_class = ('list_based_flavorpack.steps.'
                                'NumberRequestTransportStep')
            step3.order = 1
            step3.save()
            step4 = models.Step()
            step4.rule = rule2
            step4.name = 'Tracelink Number Reponse Parser'
            step4.description = ('Parses numbers from Tracelink and writes '
                                 'them persistently for use in Number '
                                 'Range module')
            step4.step_class = ('third_party_flavors.'
                                'tracelink_number_response_step.'
                                'TracelinkNumberResponseParserStep')
            step4.order = 2
            step4.save()



'''
    Copyright 2018 SerialLab, CORP

    This file is part of ListBasedFlavorpack.

    ListBasedFlavorpack is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    ListBasedFlavorpack is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with ListBasedFlavorpack.  If not, see <http://www.gnu.org/licenses/>.
'''
import uuid
from list_based_flavorpack.processing_classes.vanilla_processing.rules import NoOddRequests


class VanillaProcessingClass:
    '''
    An example of a processing  class for a list based pool/region.
    Returns UUIDs stored in memory.
    '''
    def __init__(self):
        '''
        Sets processing rules.
        '''
        self.pre_processing_rules = [NoOddRequests,]
        self.post_processing_rules = []
    
    def get_pre_processing_rules(self):
        '''
        Returns processing rules to be executed prior to the generator running.
        '''
        return self.pre_processing_rules
    
    def get_post_processing_rules(self):
        '''
        Returns processing rules to be executed after the generator has run.
        '''
        return self.post_processing_rules
    
    def get_items(self, region, size):
        first = region.last_number_line
        max_line = first + size
        region.last_number_line =  max_line
        region.save()
        return [str(uuid.uuid1()) for i in range(first, max_line)]



# Generated by Django 2.1.5 on 2019-01-23 22:21

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('list_based_flavorpack', '0002_auto_20181002_1052'),
    ]

    operations = [
        migrations.AlterField(
            model_name='listbasedregion',
            name='authentication_info',
            field=models.ForeignKey(help_text='The Authentication Info to use.', null=True, on_delete=django.db.models.deletion.SET_NULL, to='quartet_output.AuthenticationInfo', verbose_name='Authentication Info'),
        ),
        migrations.AlterField(
            model_name='listbasedregion',
            name='end_point',
            field=models.ForeignKey(help_text='A protocol-specific endpoint defining whereany data will come from', null=True, on_delete=django.db.models.deletion.SET_NULL, to='quartet_output.EndPoint', verbose_name='End Point'),
        ),
        migrations.AlterField(
            model_name='listbasedregion',
            name='number_replenishment_size',
            field=models.IntegerField(default=5000, help_text='The size that the outbound message will request from the third-party system, if numbers available are low. E.g.: 500', verbose_name='Number Replenishment Size'),
        ),
        migrations.AlterField(
            model_name='listbasedregion',
            name='processing_class_path',
            field=models.CharField(default='list_based_flavorpack.processing_classes.third_party_processing.processing.ThirdPartyProcessingClass', help_text='The full python path to the class that will be processing region allocations', max_length=150, verbose_name='Processing Class Path'),
        ),
        migrations.AlterField(
            model_name='listbasedregion',
            name='rule',
            field=models.ForeignKey(help_text='A rule that may be executed by the region processing class.', null=True, on_delete=django.db.models.deletion.SET_NULL, to='quartet_capture.Rule', verbose_name='Processing Rule'),
        ),
        migrations.AlterField(
            model_name='listbasedregion',
            name='template',
            field=models.ForeignKey(help_text='The Django/Jinja template to send a formatted request for number ranges', null=True, on_delete=django.db.models.deletion.SET_NULL, to='quartet_templates.Template', verbose_name='Message Template'),
        ),
    ]



# Generated by Django 2.1.2 on 2019-02-15 00:00

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('list_based_flavorpack', '0003_auto_20190123_1621'),
    ]

    operations = [
        migrations.AlterField(
            model_name='listbasedregion',
            name='file_id',
            field=models.UUIDField(default=uuid.uuid1),
        ),
    ]
